@@ -21,10 +21,8 @@ extern crate alloc;
 mod canon;
 mod id;
 mod implementations;
-mod repr;
 mod store;
 
 pub use canon::{Canon, CanonError, EncodeToVec};
 pub use id::{Id, IdHash};
-pub use repr::Repr;
 pub use store::{Sink, Source, Store};
